summaryrefslogtreecommitdiffstats
path: root/urpm/args.pm
diff options
context:
space:
mode:
authorRafael Garcia-Suarez <rgarciasuarez@mandriva.org>2004-04-28 08:57:58 +0000
committerRafael Garcia-Suarez <rgarciasuarez@mandriva.org>2004-04-28 08:57:58 +0000
commit6e0908fc5918ffd8b1a5b00e1c31e5056fb99af1 (patch)
tree59091464f349e55c6b5b88c73ac904e64519598d /urpm/args.pm
parentc18fd26df23f8cfc8cf0fada3af5d85ef4c33732 (diff)
downloadurpmi-6e0908fc5918ffd8b1a5b00e1c31e5056fb99af1.tar
urpmi-6e0908fc5918ffd8b1a5b00e1c31e5056fb99af1.tar.gz
urpmi-6e0908fc5918ffd8b1a5b00e1c31e5056fb99af1.tar.bz2
urpmi-6e0908fc5918ffd8b1a5b00e1c31e5056fb99af1.tar.xz
urpmi-6e0908fc5918ffd8b1a5b00e1c31e5056fb99af1.zip
Fix locale handling and the --no-locales command-line argument
Diffstat (limited to 'urpm/args.pm')
-rw-r--r--urpm/args.pm10
1 files changed, 7 insertions, 3 deletions
diff --git a/urpm/args.pm b/urpm/args.pm
index 947f7193..d5de4bdc 100644
--- a/urpm/args.pm
+++ b/urpm/args.pm
@@ -37,9 +37,13 @@ my %options_spec = (
if (defined &::usage) { ::usage() } else { die "No help defined\n" }
},
"no-locales" => sub {
- require urpm; # make sure it has been loaded
- undef *::N; undef *urpm::N;
- *::N = *urpm::N = sub { sprintf(@_) };
+ require urpm::msg; # make sure it has been loaded
+ undef *::N;
+ undef *urpm::N;
+ undef *urpm::msg::N;
+ undef *urpm::args::N;
+ *::N = *urpm::N = *urpm::msg::N = *urpm::args::N
+ = sub { my ($f, @p) = @_; sprintf($f, @p) };
},
update => \$::update,
'media|mediums=s' => \$::media,